==> aroundme_0_7_0.zip: aroundme_0_7_0/aroundme/components/core/language/1/barnraiser_01/profile.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

// we include the common language file
include_once($language_path_core . 'inc/identity_common.inc.php');


// HEADER
$lang['hdr_identity'] = 						"identity card";
$lang['hdr_network'] = 							"social network";
$lang['hdr_testimonials'] = 					"testimonials";
$lang['hdr_statistics'] = 						"statistics";


// HREF
$lang['href_invite_user'] = 					"invite into my network";
$lang['href_block_user'] =                       "block this person";


// TEXTS
$lang['txt_immediate_nw'] = 					"immediate network";
$lang['txt_nearest_conn'] = 					"nearest connection";
$lang['txt_common_nw'] = 						"people common to our networks";
$lang['txt_no_testimonials'] =                  "this person has not received any testimonials";
$lang['txt_shared_participation'] = 			"what we are doing together";
$lang['txt_degree_1'] = 						"first degree";
$lang['txt_degree_2'] = 						"second degree";
$lang['txt_degree_3'] = 						"third degree";
$lang['txt_tags'] = 							"tags";
$lang['txt_metadata'] = 						"their metadata";
$lang['txt_invited_by'] = 						"invited by";

?>

==> aroundme_0_7_4.zip: aroundme_0_7_4/aroundme/components/core/language/1/barnraiser_01/profile.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

// we include the common language file
include_once($language_path_core . 'inc/identity_common.inc.php');


// HEADER
$lang['hdr_identity'] = 						"identity card";
$lang['hdr_network'] = 							"respected network";
$lang['hdr_testimonials'] = 					"testimonials";
$lang['hdr_statistics'] = 						"statistics";


// HREF
$lang['href_invite_user'] = 					"invite into my network";
$lang['href_block_user'] =                       "block this person";
$lang['href_respect'] = 						"show respect";
$lang['href_respect_portable'] = 				"add to my flock";
$lang['href_tie_matrix'] =						"matrix";


// TEXTS
$lang['txt_immediate_nw'] = 					"immediate network";
$lang['txt_nearest_conn'] = 					"nearest connection";
$lang['txt_common_nw'] = 						"people common to our networks";
$lang['txt_no_testimonials'] =                  "this person has not received any testimonials";
$lang['txt_shared_participation'] = 			"what we are doing together";
$lang['txt_degree_1'] = 						"first degree";
$lang['txt_degree_2'] = 						"second degree";
$lang['txt_degree_3'] = 						"third degree";
$lang['txt_tags'] = 							"tags";
$lang['txt_metadata'] = 						"their metadata";
$lang['txt_invited_by'] = 						"invited by";
$lang['txt_write_testimonial'] = 				"write testimonial";

?>
